@@ -93,7 +93,7 @@ on_pipe_read2(uv_pipe_t* handle, int nread, uv_buf_t buf, uv_handle_type pending
     py_pending = PyInt_FromLong((long)pending);
 
     if (nread >= 0) {
-        data = PyString_FromStringAndSize(buf.base, nread);
+        data = PyBytes_FromStringAndSize(buf.base, nread);
         py_errorno = Py_None;
         Py_INCREF(Py_None);
     } else if (nread < 0) {
