@@ -60,7 +60,7 @@ on_udp_read(uv_udp_t* handle, int nread, uv_buf_t buf, struct sockaddr* addr, un
             uv_ip6_name(&addr6, ip, INET6_ADDRSTRLEN);
             address_tuple = Py_BuildValue("(si)", ip, ntohs(addr6.sin6_port));
         }
-        data = PyString_FromStringAndSize(buf.base, nread);
+        data = PyBytes_FromStringAndSize(buf.base, nread);
         py_errorno = Py_None;
         Py_INCREF(Py_None);
     } else if (nread < 0) {
@@ -136,6 +136,7 @@ on_udp_send(uv_udp_send_t* req, int status)
         for (i = 0; i < send_data->buf_count; i++) {
             PyMem_Free(send_data->bufs[i].base);
         }
+        PyMem_Free(send_data->bufs);
     }
     PyMem_Free(send_data);
     Py_DECREF(callback);
@@ -161,8 +162,8 @@ UDP_func_bind(UDP *self, PyObject *args)
         return NULL;
     }
 
-    if (bind_port < 0 || bind_port > 65536) {
-        PyErr_SetString(PyExc_ValueError, "port must be between 0 and 65536");
+    if (bind_port < 0 || bind_port > 65535) {
+        PyErr_SetString(PyExc_ValueError, "port must be between 0 and 65535");
         return NULL;
     }
 
@@ -273,8 +274,8 @@ UDP_func_send(UDP *self, PyObject *args)
         return NULL;
     }
 
-    if (dest_port < 0 || dest_port > 65536) {
-        PyErr_SetString(PyExc_ValueError, "port must be between 0 and 65536");
+    if (dest_port < 0 || dest_port > 65535) {
+        PyErr_SetString(PyExc_ValueError, "port must be between 0 and 65535");
         return NULL;
     }
 
@@ -387,8 +388,8 @@ UDP_func_sendlines(UDP *self, PyObject *args)
         return NULL;
     }
 
-    if (dest_port < 0 || dest_port > 65536) {
-        PyErr_SetString(PyExc_ValueError, "port must be between 0 and 65536");
+    if (dest_port < 0 || dest_port > 65535) {
+        PyErr_SetString(PyExc_ValueError, "port must be between 0 and 65535");
         return NULL;
     }
 
@@ -456,8 +457,8 @@ UDP_func_sendlines(UDP *self, PyObject *args)
                 Py_DECREF(iter);
                 goto error;
             }
-            data_str = PyString_AS_STRING(encoded);
-            data_len = PyString_GET_SIZE(encoded);
+            data_str = PyBytes_AS_STRING(encoded);
+            data_len = PyBytes_GET_SIZE(encoded);
             tmp = (char *) PyMem_Malloc(data_len);
             if (!tmp) {
                 Py_DECREF(item);
