@@ -1,7 +1,9 @@
 #!/usr/bin/env python
 
+from __future__ import print_function
+
 import sys
 
-print sys.argv[1]
+print(sys.argv[1])
 sys.stdout.flush()
 
